<?php

use ReCaptcha\RequestParameters;

/**
 * Sends POST requests to the reCAPTCHA service.
 */
class FakeCheck extends ReCaptcha\RequestMethod\Post
{
    public function submit(RequestParameters $params)
    {
        return '{"success": true, "hostname": "debian.local"}';
    }
}
